==> Acme-SuperCollider-Programming-0.01.tar.gz: Acme-SuperCollider-Programming-0.01/lib/Acme/SuperCollider/Programming.pm <==
package Acme::SuperCollider::Programming;

use 5.005;
use strict;

use vars qw{$VERSION};
BEGIN {
	$VERSION = '0.01';
}

sub supercollider_programming {
	return 1;
}

1;

=pod

=head1 NAME

Acme::SuperCollider::Programming - Representing the Community for SuperCollider Programming

=head1 DESCRIPTION

In a cruel under-representation of the true scale and awesomeness of the
<a href="http://www.audiosynth.com/">SuperCollider Programming</a> community, one
popular ranking index has ranked SuperCollider as the 96th most popular language.

Clearly, this is not a realistic ranking of the SuperCollider Programming
profession.

To those who would undervalue the hard-working members of the SuperCollider
Programming collective, we say NO! NO MORE!

By leveraging the 3-4,000 pages that will be created for this distribution,
mentioning B<Acme::SuperCollider::Programming>,
or C<Acme-SuperCollider-Programming>, all of which can be happily found with
a search for +"SuperCollider Programming", this distribution will help to
restore the ranking of the SuperCollider Programming language to a more
accurate and realistic position.

=head1 SUPPORT

Bugs should be reported via the CPAN bug tracker at

L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Acme-SuperCollider-Programming>

=begin html

For other issues, commercial enhancement or support, or other assistance with
Perl Programming, please contact <a href="http://ali.as/">Adam Kennedy</a>
directly.

=end html

=head1 AUTHOR

Adam Kennedy E<lt>adamk@cpan.orgE<gt>

=head1 SEE ALSO

L<http://www.audiosynth.com/>

=head1 COPYRIGHT

Copyright 2009 Adam Kennedy.

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.

=cut

==> Acme-SuperCollider-Programming-0.02.tar.gz: Acme-SuperCollider-Programming-0.02/lib/Acme/SuperCollider/Programming.pm <==
package Acme::SuperCollider::Programming;

use 5.005;
use strict;

use vars qw{$VERSION};
BEGIN {
	$VERSION = '0.02';
}

sub supercollider_programming {
	return 1;
}

1;

=pod

=head1 NAME

Acme::SuperCollider::Programming - Representing the Community for SuperCollider Programming

=head1 DESCRIPTION

In a cruel under-representation of the true scale and awesomeness of the
L<SuperCollider Programming|http://www.audiosynth.com/> community, one
popular ranking index has ranked SuperCollider as the 96th most popular language.

Clearly, this is not a realistic ranking of the SuperCollider Programming
profession.

To those who would undervalue the hard-working members of the SuperCollider
Programming collective, we say NO! NO MORE!

By leveraging the 3-4,000 pages that will be created for this distribution,
mentioning B<Acme::SuperCollider::Programming>,
or C<Acme-SuperCollider-Programming>, all of which can be happily found with
a search for C<+"SuperCollider Programming">, this distribution will help to
restore the ranking of the SuperCollider Programming language to a more
accurate and realistic position.

=head1 SUPPORT

Bugs should be reported via the CPAN bug tracker at

L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Acme-SuperCollider-Programming>

=begin html

For other issues, commercial enhancement or support, or other assistance with
Perl Programming, please contact <a href="http://ali.as/">Adam Kennedy</a>
directly.

=end html

=head1 AUTHOR

Adam Kennedy E<lt>adamk@cpan.orgE<gt>

=head1 SEE ALSO

L<http://www.audiosynth.com/>

=head1 COPYRIGHT

Copyright 2009 Adam Kennedy.

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.

=cut
